@@ -564,9 +564,11 @@ column_manager_init (GvaColumnManager *manager)
                 column, renderer, (GtkTreeCellDataFunc)
                 column_manager_render_title, NULL, NULL);
 
-        /* Initialize the vertical box. */
+        /* Initialize the vertical button box. */
 
-        vbox = gtk_vbox_new (FALSE, 6);
+        vbox = gtk_vbutton_box_new ();
+        gtk_box_set_spacing (GTK_BOX (vbox), 6);
+        gtk_button_box_set_layout (GTK_BUTTON_BOX (vbox), GTK_BUTTONBOX_START);
         manager->vbox = g_object_ref_sink (vbox);
 
         widget = gtk_button_new_with_mnemonic (_("Move _Up"));
@@ -612,10 +614,6 @@ column_manager_init (GvaColumnManager *manager)
         g_signal_connect_swapped (
                 priv->hide_button, "clicked",
                 G_CALLBACK (column_manager_hide_selected), manager);
-
-        /* Expand and fill to keep the buttons in place. */
-        widget = gtk_alignment_new (0.5, 0.5, 1.0, 1.0);
-        gtk_box_pack_end (GTK_BOX (vbox), widget, TRUE, TRUE, 0);
 }
 
 GType
@@ -646,6 +644,14 @@ gva_column_manager_get_type (void)
         return type;
 }
 
+/**
+ * gva_column_manager_new:
+ * @managed_view: a #GtkTreeView to manage
+ *
+ * Creates a new #GtkColumnManager.
+ *
+ * Returns: a new #GtkColumnManager
+ **/
 GtkWidget *
 gva_column_manager_new (GtkTreeView *managed_view)
 {
@@ -655,6 +661,14 @@ gva_column_manager_new (GtkTreeView *managed_view)
                 GVA_TYPE_COLUMN_MANAGER, "managed-view", managed_view, NULL);
 }
 
+/**
+ * gva_column_manager_get_managed_view:
+ * @manager: a #GvaColumnManager
+ *
+ * Returns the #GtkTreeView being managed.
+ *
+ * Returns: the #GtkTreeView being managed
+ **/
 GtkTreeView *
 gva_column_manager_get_managed_view (GvaColumnManager *manager)
 {
@@ -663,6 +677,14 @@ gva_column_manager_get_managed_view (GvaColumnManager *manager)
         return manager->priv->managed_view;
 }
 
+/**
+ * gva_column_manager_set_managed_view:
+ * @manager: a #GvaColumnManager
+ * @managed_view: a #GtkTreeView to manage
+ *
+ * Sets a new #GtkTreeView to manage.  The widget will be updated
+ * appropriately.
+ **/
 void
 gva_column_manager_set_managed_view (GvaColumnManager *manager,
                                      GtkTreeView *managed_view)
