@@ -16,6 +16,13 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+/**
+ * SECTION: gva-properties
+ * @short_description: Properties Window
+ *
+ * These functions manipulate the Properties window.
+ **/
+
 #ifndef GVA_PROPERTIES_H
 #define GVA_PROPERTIES_H
 
@@ -25,6 +32,11 @@ G_BEGIN_DECLS
 
 void            gva_properties_init             (void);
 
+/* Signal Handlers */
+
+void            gva_properties_close_clicked_cb (GtkWindow *window,
+                                                 GtkButton *button);
+
 G_END_DECLS
 
 #endif /* GVA_PROPERTIES_H */
