@@ -27,6 +27,7 @@
 #include <gnome.h>
 #endif
 
+#include "gva-audit.h"
 #include "gva-db.h"
 #include "gva-error.h"
 #include "gva-history.h"
@@ -166,12 +167,13 @@ main (gint argc, gchar **argv)
                 g_print ("%s\n", MAME_PROGRAM);
                 exit (0);
         }
-        
+
         gtk_window_set_default_icon_name (PACKAGE);
 
         if (!gva_db_init (&error))
                 g_error ("%s", error->message);
 
+        gva_audit_init ();
         gva_main_init ();
         gva_play_back_init ();
         gva_preferences_init ();
